@@ -1,14 +1,21 @@
+import six
 import sqlalchemy as sa
 from sqlalchemy import types
 from .exc import UnknownIdentityException
 
 
+def strip_string(value):
+    if isinstance(value, six.string_types):
+        return value.strip()
+    return value
+
+
 def is_scalar(value):
-    return isinstance(value, (type(None), str, int, float, bool, unicode))
+    return isinstance(value, (type(None), six.text_type, int, float, bool))
 
 
 def null_or_unicode(value):
-    return unicode(value) or None
+    return six.text_type(value) or None
 
 
 def null_or_int(value):
